The percolation is simulated on 2D square lattice with uniformly weighted sites acc and the constant parameter p.
The isotropic cluster is formed from the accessible sites connected with initial sites subset.
To form the cluster the condition acc[set+e]<p is iteratively tested for sites of the von Neumann (1,0)-neighborhood e for the current cluster perimeter set.
Von Neumann (1,0)-neighborhood on 2D square lattice consists of sites, only one coordinate of which is different from the current site by one: e=c(-1, 1, -x, x).
Forming cluster ends with the exhaustion of accessible sites in von Neumann (1,0)-neighborhood of the current cluster perimeter.